<?php

switch ($messaggio) {

case "Configura e personalizza php-residence":	$messaggio = "Configure and customize php-residence"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "cambia la lingua":  			$messaggio = "change language"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Table with all the reservations"; break;
case "Cambia la valuta":  			$messaggio = "Change currency"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "Choose the colums that will appear"; break;
case "n di settimane":  			$messaggio = "n of weeks"; break;
case "n di giorni":  				$messaggio = "n of days"; break;
case "caparra":  				$messaggio = "deposit"; break;
case "pagato":  				$messaggio = "paid"; break;
case "resto da pagare":  			$messaggio = "rest to pay"; break;
case "n di appartamento":  			$messaggio = "n of apartment"; break;
case "n di persone":  				$messaggio = "n of people"; break;
case "commento":  				$messaggio = "comment"; break;
case "costo aggiuntivo finale":  		$messaggio = "single extra cost"; break;
case "abbreviazione":  				$messaggio = "abbreviation"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "weekly extra cost"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daily extra cost"; break;
case "costo aggiuntivo percentuale":  		$messaggio = "percentage extra cost"; break;
case "cambia le colonne":  			$messaggio = "change columns"; break;
case "Tabelle dei mesi":  			$messaggio = "Months tables"; break;
case "Numero di tabelle del 2 tipo":  		$messaggio = "Number of 2nd type tables"; break;
case "cambia":  				$messaggio = "change"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "a":  					$messaggio = "to"; break;
case "La lingua  stata cambiata":  		$messaggio = "Language has been changed"; break;
case "La valuta  stata cambiata":  		$messaggio = "Currency has been changed"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Columns have been changed"; break;
case "Il numero di tabelle  stato cambiato":  	$messaggio = "The number of tables has been changed"; break;
case "Nomi dei cotratti":  			$messaggio = "Contracts names"; break;
case "contratto":  				$messaggio = "contract"; break;
case "cambia i nomi dei contratti":  		$messaggio = "change contracts names"; break;
case "I nomi dei contratti sono stati cambiati":	$messaggio = "Contracts names have been changed"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Money viewing format"; break;
case "cambia formato":  			$messaggio = "change format"; break;
case "Il formato di visualizzazione dei soldi  stato cambiato":	$messaggio = "Money viewing format has been changed"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Le date dei men a tendina sono state cambiate":	$messaggio = "Dates for drop-down menus have been changed"; break;
case "Scegli le date":  			$messaggio = "Choose dates"; break;
case "nei men a tendina":  			$messaggio = "in drop-down menus"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Truncate surnames in the tables after "; break;
case "caratteri per colonna":  			$messaggio = "characters per column"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi  stata cambiata":	$messaggio = "Surnames length in the months tables has been changed"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "Change the number of fares"; break;
case "per l'anno":  				$messaggio = "for year"; break;
case "Il numero delle tariffe  stato cambiato":	$messaggio = "The number of fares has been changed"; break;
case "Il numero di tariffe  sbagliato":  	$messaggio = "The number of fares is wrong"; break;
case "Sistema di backup":  			$messaggio = "Backup system"; break;
case "Il numero delle righe  sbagliato":  	$messaggio = "The number of rows is wrong"; break;
case "Cambia il numero delle righe":  		$messaggio = "Change the number of rows"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni  stato cambiato":	$messaggio = "The number of rows of the table with all the reservations has been changed"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite  stato cambiato":	$messaggio = "The number of rows of the payments history table has been changed"; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Payments history table"; break;
case "Il formato di visualizzazione delle date  stato cambiato":	$messaggio = "Dates viewing format has been changed"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Dates viewing format"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Table with all the clients"; break;
case "Il numero delle righe della tabella con tutti i clienti  stato cambiato":	$messaggio = "The number of rows of the table with all the clients has been changed"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "You must choose some data to insert in the group column"; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "You must insert the name of the group column"; break;
case "La colonna gruppo  stata aggiunta":  	$messaggio = "The group column has been added"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "Add a group column"; break;
case "chiamata":  				$messaggio = "called"; break;
case "con":  					$messaggio = "with"; break;
case "colonna gruppo":  			$messaggio = "group column"; break;
case "separatore":  				$messaggio = "separator"; break;
case "spazio":  				$messaggio = "space"; break;
case "trattino":  				$messaggio = "hyphen"; break;
case "a capo":  				$messaggio = "new line"; break;
case "Modelli per internet":  			$messaggio = "Internet templates"; break;
case " Do":  					$messaggio = " Su"; break;
case " Lu":  					$messaggio = " Mo"; break;
case " Ma":  					$messaggio = " Tu"; break;
case " Me":  					$messaggio = " We"; break;
case " Gi":  					$messaggio = " Th"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " Sa"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "nome della tariffa":  			$messaggio = "fare name"; break;
case "data di inserimento":  			$messaggio = "insertion date"; break;
case "tariffa completa":  			$messaggio = "complete fare"; break;
case "Gestione utenti":  			$messaggio = "Users management"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Customizations of user"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "quelle di":  				$messaggio = "those of"; break;
case "Importa i nomi dei contratti":  		$messaggio = "Import contract names"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "The duration in minutes of sessions and transactions has been changed"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "The hours of advance of the beginning of reservations have been changed"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Minutes after which consider expired not updated sessions and transactions"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Number of hours by which anticipate the moment in which reservations are considered begun"; break;
case "utente":  				$messaggio = "user"; break;
case "Interconnessioni":  			$messaggio = "Interconnections"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Automatic assignation disabled"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Automatic assignation enabled"; break;
case "Assegnazione automatica disattivata (le prenotazioni non verranno mosse dal loro appartamento)":	$messaggio = "Automatic assignation disabled (reservations will not be moved from their apartment)"; break;
case "Attiva":  				$messaggio = "Enable"; break;
case "Assegnazione automatica attivata (le prenotazioni potranno essere mosse tra gli appartamenti assegnati)":	$messaggio = "Automatic assignation enabled (reservations can be moved between assigned apartments)"; break;
case "Disattiva":  				$messaggio = "Disable"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
